@@ -8,6 +8,6 @@
 PGconn * db_connect(modopt_t *options);
 int pg_execParam(PGconn *conn, PGresult **res, const char *query, const char *service, const char *user, const char *passwd, const char *rhost);
 int backend_authenticate(const char *service, const char *user, const char *passwd, const char *rhost, modopt_t *options);
-char * password_encrypt(modopt_t *options, const char *pass, const char *salt);
+char * password_encrypt(modopt_t *options, const char *user, const char *pass, const char *salt);
 
 #endif
