@@ -65,7 +65,12 @@ pam_sm_authenticate(pam_handle_t *pamh, int flags, int argc, const char **argv)
 
 					} else {
 
-						SYSLOG("couldn't auth");
+                        char* rhost = NULL;
+                        if (pam_get_item(pamh, PAM_RHOST, (void *) &rhost) == PAM_SUCCESS) {
+                            SYSLOG("couldn't authenticate user %s (%s)", user, rhost);
+                        } else {
+                            SYSLOG("couldn't authenticate user %s", user);
+                        }
 
 					}
 
@@ -211,7 +216,7 @@ pam_sm_chauthtok(pam_handle_t *pamh, int flags, int argc, const char **argv)
 		if (rc == PAM_SUCCESS) {
 
 			if ((rc = pam_get_confirm_pass(pamh, &newpass, PASSWORD_PROMPT_NEW, PASSWORD_PROMPT_CONFIRM, options->std_flags)) == PAM_SUCCESS) {
-				if((newpass_crypt = password_encrypt(options, newpass, NULL))) {
+				if((newpass_crypt = password_encrypt(options, user, newpass, NULL))) {
 					if(!(conn = db_connect(options))) {
 						rc = PAM_AUTHINFO_UNAVAIL;
 					}
